package xyz.stachel.zombiesutils.game.recorder.files;

import net.minecraft.client.MinecraftClient;
import net.minecraft.text.Style;
import net.minecraft.text.Text;
import net.minecraft.util.Formatting;
import org.apache.commons.lang3.exception.ExceptionUtils;
import org.jetbrains.annotations.NotNull;
import xyz.stachel.zombiesutils.ZombiesUtils;
import xyz.stachel.zombiesutils.game.GameMode;
import xyz.stachel.zombiesutils.game.recorder.FileManager;
import xyz.stachel.zombiesutils.game.recorder.data.CategoryData;

import java.io.File;

public class CategoryFile extends File {
    private final CategoryData data;
    private final GameMode.Map map;
    private final GameMode.Difficulty difficulty;

    public CategoryFile(File category, @NotNull GameMode.Map map, GameMode.Difficulty difficulty) {
        // Game-directory -> custom category -> file named "MAP_DIFFICULTY.times"
        // Content encoded in StandardCharsets.UTF_16
        super(category, map + "_" + difficulty + ".times");
        this.map = map;
        this.difficulty = difficulty;
        this.data = FileManager.categoryReadOrCreate(this);
    }

    public short getBestSegment(int round) {
        return this.data.getBestSegment(round - 1);
    }

    public void setBestSegment(int round, int ticks) {
        this.data.setBestSegment(round - 1, ticks);

        try {
            FileManager.writeDataToFile(this, this.data);
        } catch (Exception e) {
            ZombiesUtils.LOGGER.error(ExceptionUtils.getStackTrace(e));
            MinecraftClient.getInstance().player.sendMessage(Text.literal("Error saving segment to splits-file. Please Contact Stachelbeere1248.").setStyle(Style.EMPTY.withColor(Formatting.RED)), false);
        }
    }

    public int getPersonalBest(int round) {
        return data.getPersonalBest(round - 1);
    }

    public void setPersonalBest(int round, int ticks) {
        this.data.setPersonalBest(round - 1, ticks);

        try {
            FileManager.writeDataToFile(this, this.data);
        } catch (Exception e) {
            ZombiesUtils.LOGGER.error(ExceptionUtils.getStackTrace(e));
            MinecraftClient.getInstance().player.sendMessage(Text.literal("Error saving pb to splits-file. Please Contact Stachelbeere1248.").setStyle(Style.EMPTY.withColor(Formatting.RED)), false);
        }
    }

    public GameMode.Map getMap() {
        return this.map;
    }

    public GameMode.Difficulty getDifficulty() {
        return this.difficulty;
    }

}